@@ -1,27 +1,31 @@
 package DBIx::Class::Storage::DBI::ODBC;
 use strict;
 use warnings;
-
 use base qw/DBIx::Class::Storage::DBI/;
 use mro 'c3';
-use Try::Tiny;
-use namespace::clean;
 
 sub _rebless {
   my ($self) = @_;
 
-  try {
-    my $dbtype = $self->_get_dbh->get_info(17);
-
+  if (my $dbtype = $self->_dbh_get_info(17)) {
     # Translate the backend name into a perl identifier
     $dbtype =~ s/\W/_/gi;
     my $subclass = "DBIx::Class::Storage::DBI::ODBC::${dbtype}";
 
-    if ($self->load_optional_class($subclass) && !$self->isa($subclass)) {
+    return if $self->isa($subclass);
+
+    if ($self->load_optional_class($subclass)) {
       bless $self, $subclass;
       $self->_rebless;
     }
-  };
+    else {
+      warn "Expected driver '$subclass' not found, using generic support. " .
+           "Please file an RT.\n";
+    }
+  }
+  else {
+    warn "Could not determine your database type, using generic support.\n";
+  }
 }
 
 1;
@@ -35,12 +39,13 @@ DBIx::Class::Storage::DBI::ODBC - Base class for ODBC drivers
 This class simply provides a mechanism for discovering and loading a sub-class
 for a specific ODBC backend.  It should be transparent to the user.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Marc Mims C<< <marc@questright.com> >>
+See L<DBIx::Class/AUTHOR> and L<DBIx::Class/CONTRIBUTORS>.
 
 =head1 LICENSE
 
 You may distribute this code under the same terms as Perl itself.
 
 =cut
+# vim:sts=2 sw=2:
